==> ejc-zdsstore-api-3.0.0-20240122.013915-148-sources.jar: com/ejianc/business/zdsstore/vo/ReturnGoodsDetailVO.java <==
package com.ejianc.business.zdsstore.vo;

import java.math.*;

import com.ejianc.business.tools.refer.annotation.ReferJsonField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 材料退货明细表
 * 
 * @author generator
 * 
 */
public class ReturnGoodsDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long storeId; // 仓库id
    private String storeName; // 仓库名称
    private Long outstoreId; // 主表id
    @ReferJsonField(referCode = "ref-zdsmteral-category",referFields = "code",resultFields = "materialTypeCode")
    private Long materialCategoryId; // 物资分类id
    private String materialTypeCode;
    private String materialCategoryName; // 物资分类名称
    @ReferJsonField(referCode = "ref-zdsmteral",referFields = "code",resultFields = "materialCode")
    private Long materialId; // 物资id
    private String materialCode;
    private String materialName; // 物资名称
    private String materialSpec; // 规格型号
    private Long materialUnitId; // 物资计量单位id
    private String materialUnitName; // 物资计量单位
    private BigDecimal instoreNum; // 入库数量
    private BigDecimal userableNum; // 剩余可用数量
    private BigDecimal returnNum; // 退货数量
    private BigDecimal contractPrice; // 合同单价
    private BigDecimal returnPrice; // 退货单价
    private BigDecimal returnTaxPrice; // 退货单价(含税)
    private BigDecimal taxRate; // 税率
    private BigDecimal mny; // 金额
    private BigDecimal taxMny; // 金额(含税)
    private BigDecimal tax; //税额
    private String memo; // 备注
    private BigDecimal detailMnyDisparity; //退货差额
    private BigDecimal detailTaxMnyDisparity; //退货差额
    private Long brandId; //品牌Id
    private String brandName; //品牌名称
    private String productCode; //产品代码

    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public BigDecimal getDetailMnyDisparity() {
        return detailMnyDisparity;
    }

    public void setDetailMnyDisparity(BigDecimal detailMnyDisparity) {
        this.detailMnyDisparity = detailMnyDisparity;
    }

    public BigDecimal getDetailTaxMnyDisparity() {
        return detailTaxMnyDisparity;
    }

    public void setDetailTaxMnyDisparity(BigDecimal detailTaxMnyDisparity) {
        this.detailTaxMnyDisparity = detailTaxMnyDisparity;
    }

    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public Long getStoreId() {
        return storeId;
    }

    public void setStoreId(Long storeId) {
        this.storeId = storeId;
    }
    public String getStoreName() {
        return storeName;
    }

    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }
    public Long getOutstoreId() {
        return outstoreId;
    }

    public void setOutstoreId(Long outstoreId) {
        this.outstoreId = outstoreId;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    public Long getMaterialUnitId() {
        return materialUnitId;
    }

    public void setMaterialUnitId(Long materialUnitId) {
        this.materialUnitId = materialUnitId;
    }
    public String getMaterialUnitName() {
        return materialUnitName;
    }

    public void setMaterialUnitName(String materialUnitName) {
        this.materialUnitName = materialUnitName;
    }
    public BigDecimal getInstoreNum() {
        return instoreNum;
    }

    public void setInstoreNum(BigDecimal instoreNum) {
        this.instoreNum = instoreNum;
    }
    public BigDecimal getUserableNum() {
        return userableNum;
    }

    public void setUserableNum(BigDecimal userableNum) {
        this.userableNum = userableNum;
    }
    public BigDecimal getReturnNum() {
        return returnNum;
    }

    public void setReturnNum(BigDecimal returnNum) {
        this.returnNum = returnNum;
    }
    public BigDecimal getContractPrice() {
        return contractPrice;
    }

    public void setContractPrice(BigDecimal contractPrice) {
        this.contractPrice = contractPrice;
    }
    public BigDecimal getReturnPrice() {
        return returnPrice;
    }

    public void setReturnPrice(BigDecimal returnPrice) {
        this.returnPrice = returnPrice;
    }
    public BigDecimal getReturnTaxPrice() {
        return returnTaxPrice;
    }

    public void setReturnTaxPrice(BigDecimal returnTaxPrice) {
        this.returnTaxPrice = returnTaxPrice;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }

    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-zdsstore-api-3.0.0-20240128.053754-162-sources.jar: com/ejianc/business/zdsstore/vo/ReturnGoodsDetailVO.java <==
package com.ejianc.business.zdsstore.vo;

import java.math.*;

import com.ejianc.business.tools.refer.annotation.ReferJsonField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 材料退货明细表
 * 
 * @author generator
 * 
 */
public class ReturnGoodsDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long storeId; // 仓库id
    private String storeName; // 仓库名称
    private Long outstoreId; // 主表id
    @ReferJsonField(referCode = "ref-zdsmteral-category",referFields = "code",resultFields = "materialTypeCode")
    private Long materialCategoryId; // 物资分类id
    private String materialTypeCode;
    private String materialCategoryName; // 物资分类名称
    @ReferJsonField(referCode = "ref-zdsmteral",referFields = "code",resultFields = "materialCode")
    private Long materialId; // 物资id
    private String materialCode;
    private String materialName; // 物资名称
    private String materialSpec; // 规格型号
    private Long materialUnitId; // 物资计量单位id
    private String materialUnitName; // 物资计量单位
    private BigDecimal instoreNum; // 入库数量
    private BigDecimal userableNum; // 剩余可用数量
    private BigDecimal returnNum; // 退货数量
    private BigDecimal contractPrice; // 合同单价
    private BigDecimal returnPrice; // 退货单价
    private BigDecimal returnTaxPrice; // 退货单价(含税)
    private BigDecimal taxRate; // 税率
    private BigDecimal mny; // 金额
    private BigDecimal taxMny; // 金额(含税)
    private BigDecimal tax; //税额
    private String memo; // 备注
    private BigDecimal detailMnyDisparity; //退货差额
    private BigDecimal detailTaxMnyDisparity; //退货差额
    private Long brandId; //品牌Id
    private String brandName; //品牌名称
    private String productCode; //产品代码

    private BigDecimal instoreTaxPrice;
    private BigDecimal instorePrice;

    public BigDecimal getInstoreTaxPrice() {
        return instoreTaxPrice;
    }

    public void setInstoreTaxPrice(BigDecimal instoreTaxPrice) {
        this.instoreTaxPrice = instoreTaxPrice;
    }

    public BigDecimal getInstorePrice() {
        return instorePrice;
    }

    public void setInstorePrice(BigDecimal instorePrice) {
        this.instorePrice = instorePrice;
    }

    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public BigDecimal getDetailMnyDisparity() {
        return detailMnyDisparity;
    }

    public void setDetailMnyDisparity(BigDecimal detailMnyDisparity) {
        this.detailMnyDisparity = detailMnyDisparity;
    }

    public BigDecimal getDetailTaxMnyDisparity() {
        return detailTaxMnyDisparity;
    }

    public void setDetailTaxMnyDisparity(BigDecimal detailTaxMnyDisparity) {
        this.detailTaxMnyDisparity = detailTaxMnyDisparity;
    }

    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public Long getStoreId() {
        return storeId;
    }

    public void setStoreId(Long storeId) {
        this.storeId = storeId;
    }
    public String getStoreName() {
        return storeName;
    }

    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }
    public Long getOutstoreId() {
        return outstoreId;
    }

    public void setOutstoreId(Long outstoreId) {
        this.outstoreId = outstoreId;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    public Long getMaterialUnitId() {
        return materialUnitId;
    }

    public void setMaterialUnitId(Long materialUnitId) {
        this.materialUnitId = materialUnitId;
    }
    public String getMaterialUnitName() {
        return materialUnitName;
    }

    public void setMaterialUnitName(String materialUnitName) {
        this.materialUnitName = materialUnitName;
    }
    public BigDecimal getInstoreNum() {
        return instoreNum;
    }

    public void setInstoreNum(BigDecimal instoreNum) {
        this.instoreNum = instoreNum;
    }
    public BigDecimal getUserableNum() {
        return userableNum;
    }

    public void setUserableNum(BigDecimal userableNum) {
        this.userableNum = userableNum;
    }
    public BigDecimal getReturnNum() {
        return returnNum;
    }

    public void setReturnNum(BigDecimal returnNum) {
        this.returnNum = returnNum;
    }
    public BigDecimal getContractPrice() {
        return contractPrice;
    }

    public void setContractPrice(BigDecimal contractPrice) {
        this.contractPrice = contractPrice;
    }
    public BigDecimal getReturnPrice() {
        return returnPrice;
    }

    public void setReturnPrice(BigDecimal returnPrice) {
        this.returnPrice = returnPrice;
    }
    public BigDecimal getReturnTaxPrice() {
        return returnTaxPrice;
    }

    public void setReturnTaxPrice(BigDecimal returnTaxPrice) {
        this.returnTaxPrice = returnTaxPrice;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }

    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
